==> pf4-component-mapper-3.18.0.tgz: package/esm/dual-list-tree-select/dual-list-tree-select.js <==
import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
var _excluded = ["label", "isRequired", "helperText", "meta", "validateOnMount", "description", "hideLabel", "id", "input", "FormGroupProps", "options", "isSortable"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { useState } from 'react';
import PropTypes from 'prop-types';
import { DualListSelector } from "@patternfly/react-core/dist/esm/components/DualListSelector/DualListSelector.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import _isEqual from 'lodash/isEqual';
import FormGroup from '../form-group';
import DualListContext from '../dual-list-context';
export var convertOptions = function convertOptions(options, sort) {
  if (Array.isArray(options)) {
    var result = options.map(function (option) {
      return convertOptions(option, sort);
    }).filter(Boolean);

    if (sort) {
      var sortFn = function sortFn(a, b) {
        return sort === 'asc' ? a.localeCompare(b) : b.localeCompare(a);
      };

      result = result.sort(function (a, b) {
        return sortFn(a.text || a.label, b.text || b.label);
      });
    }

    return result;
  }

  return _objectSpread(_objectSpread({
    text: options.label,
    id: options.value || options.key || options.label || options.text,
    isChecked: false
  }, options), options.children && {
    children: convertOptions(options.children, sort).filter(Boolean)
  });
};
export var selectedOptions = function selectedOptions(options, value, selected) {
  if (Array.isArray(options)) {
    return options.map(function (option) {
      return selectedOptions(option, value, selected);
    }).filter(Boolean);
  }

  if (options.value) {
    if (selected ? value.includes(options.value) : !value.includes(options.value)) {
      return options;
    }
  }

  if (options.children) {
    var someSelected = selectedOptions(options.children, value, selected).filter(Boolean);

    if (someSelected.length) {
      return _objectSpread(_objectSpread({}, options), {}, {
        children: someSelected
      });
    }
  }
};
export var getValueFromSelected = function getValueFromSelected(options) {
  var newValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];

  if (Array.isArray(options)) {
    options.map(function (option) {
      return getValueFromSelected(option, newValue);
    });
  }

  if (options.value) {
    newValue.push(options.value);
  }

  if (options.children) {
    getValueFromSelected(options.children, newValue);
  }

  return newValue;
};

var DualListTreeSelect = function DualListTreeSelect(props) {
  var _useFieldApi = useFieldApi(_objectSpread(_objectSpread({}, props), {}, {
    FieldProps: {
      isEqual: function isEqual(current, initial) {
        return _isEqual(_toConsumableArray(current || []).sort(), _toConsumableArray(initial || []).sort());
      }
    }
  })),
      label = _useFieldApi.label,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      description = _useFieldApi.description,
      hideLabel = _useFieldApi.hideLabel,
      id = _useFieldApi.id,
      input = _useFieldApi.input,
      FormGroupProps = _useFieldApi.FormGroupProps,
      options = _useFieldApi.options,
      isSortable = _useFieldApi.isSortable,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var _useState = useState(function () {
    return {
      left: isSortable && 'asc',
      right: isSortable && 'asc'
    };
  }),
      _useState2 = _slicedToArray(_useState, 2),
      sortConfig = _useState2[0],
      setSortConfig = _useState2[1];

  var value = input.value || [];
  var leftOptions = selectedOptions(options, value, false);
  var rightOptions = selectedOptions(options, value, true);

  var onListChange = function onListChange(_newLeft, newRight) {
    return input.onChange(getValueFromSelected(newRight));
  };

  return /*#__PURE__*/React.createElement(FormGroup, {
    label: label,
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: hideLabel,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, /*#__PURE__*/React.createElement(DualListContext.Provider, {
    value: {
      sortConfig: sortConfig,
      setSortConfig: setSortConfig
    }
  }, /*#__PURE__*/React.createElement(DualListSelector, _extends({
    availableOptions: convertOptions(leftOptions, sortConfig.left),
    chosenOptions: convertOptions(rightOptions, sortConfig.right),
    onListChange: onListChange,
    id: id || input.name,
    isTree: true
  }, rest))));
};

DualListTreeSelect.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  id: PropTypes.string,
  isSearchable: PropTypes.bool,
  isSortable: PropTypes.bool
};
export default DualListTreeSelect;

==> pf4-component-mapper-3.23.0.tgz: package/esm/dual-list-tree-select/dual-list-tree-select.js <==
import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
var _excluded = ["label", "isRequired", "helperText", "meta", "validateOnMount", "description", "hideLabel", "id", "input", "FormGroupProps", "options", "isSortable"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { useState } from 'react';
import PropTypes from 'prop-types';
import { DualListSelector } from "@patternfly/react-core/dist/dynamic/components/DualListSelector";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import _isEqual from 'lodash/isEqual';
import FormGroup from '../form-group';
import DualListContext from '../dual-list-context';
export var convertOptions = function convertOptions(options, sort) {
  if (Array.isArray(options)) {
    var result = options.map(function (option) {
      return convertOptions(option, sort);
    }).filter(Boolean);

    if (sort) {
      var sortFn = function sortFn(a, b) {
        return sort === 'asc' ? a.localeCompare(b) : b.localeCompare(a);
      };

      result = result.sort(function (a, b) {
        return sortFn(a.text || a.label, b.text || b.label);
      });
    }

    return result;
  }

  return _objectSpread(_objectSpread({
    text: options.label,
    id: options.value || options.key || options.label || options.text,
    isChecked: false
  }, options), options.children && {
    children: convertOptions(options.children, sort).filter(Boolean)
  });
};
export var selectedOptions = function selectedOptions(options, value, selected) {
  if (Array.isArray(options)) {
    return options.map(function (option) {
      return selectedOptions(option, value, selected);
    }).filter(Boolean);
  }

  if (options.value) {
    if (selected ? value.includes(options.value) : !value.includes(options.value)) {
      return options;
    }
  }

  if (options.children) {
    var someSelected = selectedOptions(options.children, value, selected).filter(Boolean);

    if (someSelected.length) {
      return _objectSpread(_objectSpread({}, options), {}, {
        children: someSelected
      });
    }
  }
};
export var getValueFromSelected = function getValueFromSelected(options) {
  var newValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];

  if (Array.isArray(options)) {
    options.map(function (option) {
      return getValueFromSelected(option, newValue);
    });
  }

  if (options.value) {
    newValue.push(options.value);
  }

  if (options.children) {
    getValueFromSelected(options.children, newValue);
  }

  return newValue;
};

var DualListTreeSelect = function DualListTreeSelect(props) {
  var _useFieldApi = useFieldApi(_objectSpread(_objectSpread({}, props), {}, {
    FieldProps: {
      isEqual: function isEqual(current, initial) {
        return _isEqual(_toConsumableArray(current || []).sort(), _toConsumableArray(initial || []).sort());
      }
    }
  })),
      label = _useFieldApi.label,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      description = _useFieldApi.description,
      hideLabel = _useFieldApi.hideLabel,
      id = _useFieldApi.id,
      input = _useFieldApi.input,
      FormGroupProps = _useFieldApi.FormGroupProps,
      options = _useFieldApi.options,
      isSortable = _useFieldApi.isSortable,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var _useState = useState(function () {
    return {
      left: isSortable && 'asc',
      right: isSortable && 'asc'
    };
  }),
      _useState2 = _slicedToArray(_useState, 2),
      sortConfig = _useState2[0],
      setSortConfig = _useState2[1];

  var value = input.value || [];
  var leftOptions = selectedOptions(options, value, false);
  var rightOptions = selectedOptions(options, value, true);

  var onListChange = function onListChange(_e, _newLeft, newRight) {
    return input.onChange(getValueFromSelected(newRight));
  };

  return /*#__PURE__*/React.createElement(FormGroup, {
    label: label,
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: hideLabel,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, /*#__PURE__*/React.createElement(DualListContext.Provider, {
    value: {
      sortConfig: sortConfig,
      setSortConfig: setSortConfig
    }
  }, /*#__PURE__*/React.createElement(DualListSelector, _extends({
    availableOptions: convertOptions(leftOptions, sortConfig.left),
    chosenOptions: convertOptions(rightOptions, sortConfig.right),
    onListChange: onListChange,
    id: id || input.name,
    isTree: true
  }, rest))));
};

DualListTreeSelect.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  id: PropTypes.string,
  isSearchable: PropTypes.bool,
  isSortable: PropTypes.bool
};
export default DualListTreeSelect;
